<?php
/**
 * @version		1.0
 * @package		Joomla
 * @subpackage	Content
 * @author 		Whiletrue.it  http://www.whiletrue.it 
 * @copyright	Copyright (C) Whiletrue.it . All rights reserved.
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

// Check to ensure this file is included in Joomla!
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.plugin.plugin' );

/**
 * Example Content Plugin
 *
 * @package		Joomla
 * @subpackage	Content
 * @since 		1.5
 */
class plgContentReadingtime extends JPlugin
{

	/**
	 * Constructor
	 *
	 * For php4 compatability we must not use the __constructor as a constructor for plugins
	 * because func_get_args ( void ) returns a copy of all passed arguments NOT references.
	 * This causes problems with cross-referencing necessary for the observer design pattern.
	 *
	 * @param object $subject The object to observe
	 * @param object $params  The object that holds the plugin parameters
	 * @since 1.5
	 */
	function plgContentReadingtime( &$subject, $params )
	{
		parent::__construct( $subject, $params );
	}

	/**
	 * Example prepare content method
	 *
	 * Method is called by the view
	 *
	 * @param 	object		The article object.  Note $article->text is also available
	 * @param 	object		The article params
	 * @param 	int			The 'page' number
	 */
	function onPrepareContent( &$article, &$params, $limitstart )
	{
		global $mainframe;
		
		$regex = "/{readingtime}([0-9]*){\/readingtime}/i";

		// Se il plugin è attivato e se viene trovata la stringa {aboutme} all'interno del contenuto
		if ($this->params->get( 'enabled', 0 )) {
			//	$article->text = preg_replace( $regex, '', $article->text);
			return false;
		}
	
		$matches_number = preg_match( $regex, $article->text, $match); 

		if ($matches_number==0) {
			return false;
		}		

		// IF TIME IS NOT PROVIDED, USE THE DEFAULT PLUGIN VALUE
		$default_reading_time = (is_numeric($match[1])) ? $match[1] : $this->params->get('time', NULL);
		if (!is_numeric($default_reading_time)) {
			$default_reading_time = 150;
		}

		$barcolor = $this->params->get('barcolor', NULL);
		$text = $this->params->get('text', NULL);
		$text = str_replace('SSSS', $default_reading_time, $text);

		$out = '
			<style>
				.readingtime_border { border:1px solid black;width:200px;height:10px; }
				.readingtime_bar { background-color:'.$barcolor.';width:0px;height:10px; }
			</style>
			
			<div id="readingtime_text"></div>
			<div id="readingtime_bar_out">
				<div id="readingtime_bar_in" class="readingtime_bar"></div>
			</div>
		
			<script type="text/javascript">
			if (typeof jQuery == "undefined") { 
				document.write("'.JText::_('Plugin Readingtime warning jQuery javascript library not loaded').'");
			} else {
 			   // jQuery is loaded  
				jQuery("#readingtime_text").append("'.$text.'");
				jQuery("#readingtime_bar_out").addClass("readingtime_border");

				jQuery("#readingtime_bar_in").animate({
				    width: "100%"
				}, '.$default_reading_time.'*1000);
			}			
			</script>
			';
		
        $article->text = preg_replace($regex, $out, $article->text);
		return true;
	}

	/**
	 * Example after display title method
	 *
	 * Method is called by the view and the results are imploded and displayed in a placeholder
	 *
	 * @param 	object		The article object.  Note $article->text is also available
	 * @param 	object		The article params
	 * @param 	int			The 'page' number
	 * @return	string
	 */
	function onAfterDisplayTitle( &$article, &$params, $limitstart )
	{
		global $mainframe;

		return '';
	}

	/**
	 * Example before display content method
	 *
	 * Method is called by the view and the results are imploded and displayed in a placeholder
	 *
	 * @param 	object		The article object.  Note $article->text is also available
	 * @param 	object		The article params
	 * @param 	int			The 'page' number
	 * @return	string
	 */
	function onBeforeDisplayContent( &$article, &$params, $limitstart )
	{
		global $mainframe;

		return '';
	}

	/**
	 * Example after display content method
	 *
	 * Method is called by the view and the results are imploded and displayed in a placeholder
	 *
	 * @param 	object		The article object.  Note $article->text is also available
	 * @param 	object		The article params
	 * @param 	int			The 'page' number
	 * @return	string
	 */
	function onAfterDisplayContent( &$article, &$params, $limitstart )
	{
		global $mainframe;

		return '';
	}

	/**
	 * Example before save content method
	 *
	 * Method is called right before content is saved into the database.
	 * Article object is passed by reference, so any changes will be saved!
	 * NOTE:  Returning false will abort the save with an error.
	 * 	You can set the error by calling $article->setError($message)
	 *
	 * @param 	object		A JTableContent object
	 * @param 	bool		If the content is just about to be created
	 * @return	bool		If false, abort the save
	 */
	function onBeforeContentSave( &$article, $isNew )
	{
		global $mainframe;

		return true;
	}

	/**
	 * Example after save content method
	 * Article is passed by reference, but after the save, so no changes will be saved.
	 * Method is called right after the content is saved
	 *
	 *
	 * @param 	object		A JTableContent object
	 * @param 	bool		If the content is just about to be created
	 * @return	void
	 */
	function onAfterContentSave( &$article, $isNew )
	{
		global $mainframe;

		return true;
	}

}
